# shelter: couch

- [parts](./parts/)
- [validation](./validation.md)

|   |   |   |
| --- | --- | --- |
| [![image](https://github.com/kamangir/assets2/raw/main/shelter/01.png?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/01.png?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/02.png?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/02.png?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/03.png?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/03.png?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/shelter/04.png?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/04.png?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251005_180841.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251005_180841.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251006_181432.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251006_181432.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251006_181509.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251006_181509.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251006_181554.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251006_181554.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251028_113245.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251028_113245.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251103_182323.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251103_182323.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251104_000755.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251104_000755.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251109_000501.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251109_000501.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251109_000641.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251109_000641.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251109_002124.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251109_002124.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251109_002639.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251109_002639.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251124_094744.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251124_094744.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251202_101949.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251202_101949.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251202_102912.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251202_102912.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251231_095746.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251231_095746.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251231_100222.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251231_100222.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/raw/main/shelter/20251231_100305.jpg?raw=true)](https://github.com/kamangir/assets2/raw/main/shelter/20251231_100305.jpg?raw=true) |
